@@ -19,7 +19,7 @@ def session(default=True, **kwargs):
     return _session
 
 
-@session(python=["3.8", "3.9", "3.10", "3.11", "pypy3"])
+@session(python=["3.8", "3.9", "3.10", "3.11", "3.12", "pypy3"])
 def tests(session):
     session.install(ROOT, "-r", TESTS / "requirements.txt")
     if session.posargs == ["coverage"]:
